@@ -18,6 +18,10 @@ package Image::BMP;
 # CHANGELOG
 # ---------
 #
+# Version 1.19 2016/05/22
+# -----------------------
+# * Stupid filehandle bug fix for view_ascii
+#
 # Version 1.18 2016/05/21
 # -----------------------
 # * Fix for non-byte indexes, reads and writes (Thanks for the inspiration, Mike Paolucci)
@@ -58,7 +62,7 @@ use Exporter ();
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(open_file open_pipe close load colormap xy xy_rgb xy_index set save view_ascii debug remember_image ignore_imagemagick_bug add_pixel file);
 
-$VERSION = '1.18';
+$VERSION = '1.19';
 $LIBRARY = __PACKAGE__;
 
 ##################################################
@@ -745,8 +749,12 @@ sub xy_rgb {
 sub view_ascii {
 	my ($bmp,$file) = @_;
 
-	$file = '>&STDOUT' if !$file || $file eq '-';
-	open(my $fh,'>', $file) || fatal("Couldn't open view_ascii output [$file]");
+	my $fh;
+	if (!$file || $file eq '-') {
+		open($fh,'>&STDOUT') || fatal("Can't dup STDOUT for view_ascii??");
+	} else {
+		open($fh,'>', $file) || fatal("Couldn't open view_ascii output [$file]");
+	}
 
 	$bmp->needs_image("use view_ascii method");
 
@@ -891,7 +899,7 @@ Lookup or set a pixel in the image by index.
 Lookup or set a pixel in the image by rgb values.
 (Calls C<load> if necessary)
 
-=item $img->view_ascii;
+=item $img->view_ascii( [$file] );
 
 Do a print of the image in crude ASCII fashion.
 Useful for debugging of small images.
